require 'pgplot'

-- setup parameters
local n = 4
local petals = 5
local phase = 2 * math.pi / petals / n
if math.mod(petals, 2) == 0 then phase = phase / 2 end
local nsamples = 500
local tmin = 0
local tmax = 2 * math.pi
local dt = (tmax - tmin) / nsamples

-- plot
local device = 'flower.png/PNG'
assert(pgplot.start(device) > 0, 'can\'t initialize device')
pgplot.setcolorbyname(0, 'white')
pgplot.setcolorbyname(1, 'black')
pgplot.setcharheight(0.75)
local _, mc = pgplot.getcolorcap()
pgplot.setcharfont(2) -- roman
pgplot.environ(-1.1, 1.1, -1.1, 1.1)
pgplot.setcharheight(1)
pgplot.setcharfont(3) -- italic
pgplot.label('', '', 'Flower')
pgplot.beginbuffer()
for i = 1, n do
	-- set color
	if mc > 1 then
		pgplot.setcolorindex(math.mod(i - 1, mc - 1) + 2)
	end
	-- plot parametric
	local x = {}
	local y = {}
	local t = tmin
	for j = 1, nsamples do -- generate coords
		-- rho[i](t) = sin(petals*(t - (i-1)*phase))
		local a = petals * (t - (i-1)*phase)
		x[j] = math.sin(a) * math.cos(t)
		y[j] = math.sin(a) * math.sin(t)
		t = t + dt
	end
	pgplot.line(x, y)
end
pgplot.setfillstyle(3) -- hatched
pgplot.setcolorindex(7)
pgplot.sethatchingstyle(45, 0.5, 0)
pgplot.circle(0, 0, 0.2)
pgplot.setcolorindex(8)
pgplot.sethatchingstyle(-45, 0.5, 0)
pgplot.circle(0, 0, 0.2)
-- reset
pgplot.setcolorindex()
pgplot.endbuffer()
pgplot.finish()

