require 'pgplot'

-- setup data
local n = 200
local f = function(x) return x == 0 and 0 or math.sin(1/x) end
local xmin = -1
local xmax = 1
local fmin = f(xmin)
local fmax = fmin
local x = {}
local d = {}
for i = 1, n do
	x[i] = xmin + (xmax - xmin) * (i - 1) / n
	d[i] = f(x[i])
	if fmin > d[i] then fmin = d[i] end
	if fmax < d[i] then fmax = d[i] end
end
-- add randomness
local r1 = {}
local r2 = {}
local scale = 0.05
for i = 1, n do
	r1[i] = d[i] + scale * (xmin + (xmax - xmin) * math.random())
	r2[i] = d[i] + 2 * scale * (xmin + (xmax - xmin) * math.random())
end

-- plot
-- set device
local device = 'graph.ps/CPS'
assert(pgplot.start(device) > 0, 'can\'t initialize device')
pgplot.setcolorbyname(0, 'white')
pgplot.setcolorbyname(1, 'black')
pgplot.setcharheight(0.75)
-- set environment
local dx = scale * (xmax - xmin)
local df = scale * (fmax - fmin)
pgplot.environ(xmin - dx, xmax + dx, fmin - df, fmax + df)
pgplot.label('\\fr(x)', '\\fr(y)',
		'Graph function with error data: \\fisin(1/x)')
-- plot function with data
pgplot.SAMEPLOT = true
pgplot.setcolorindex(1) -- black
pgplot.setlinewidth(3)
pgplot.graph(x, d)
pgplot.setlinewidth() -- reset
pgplot.setcolorindex(2) -- red
pgplot.data(x, r1, 4)
pgplot.setcolorindex(4) -- blue
pgplot.data(x, r2, 7)
-- finish
pgplot.finish()
