require 'pgplot'

-- initialize
pgplot.startx()
pgplot.ask(true)

-- demo 1
local xs = {1.0, 2.0, 3.0, 4.0, 5.0};
local ys = {1.0, 4.0, 9.0, 16.0, 25.0};
local xr = {}
local yr = {}
local n = 60
for i = 1, n do
	xr[i] = 0.1 * i
	yr[i] = xr[i] * xr[i]
end
pgplot.environ(0.0, 10.0, 0.0, 20.0, 0, 1)
pgplot.label('(x)', '(y)', 'y = x\\u2\\d')
pgplot.point(xs, ys)
pgplot.line(xr, yr)

-- demo 2
local nx = 40
local ny = 40
local f = {}
local fmin = 0
local fmax = 0
for i = 1, nx do
	f[i] = {}
	for j = 1, ny do
		local x = math.cos(0.3*math.sqrt(i*2)-0.13333*j)*math.cos(0.13333*i)
				+ (i-j)/nx
		fmin = math.min(x, fmin)
		fmax = math.max(x, fmax)
		f[i][j] = x
	end
end
-- clear screen, set up window and viewport
pgplot.newpage()
pgplot.setviewport(0.05, 0.95, 0.05, 0.95)
pgplot.setwindow(1.0, nx, 1.0, ny)
pgplot.box('bcts', 0.0, 0, 'bcts', 0.0, 0)
pgplot.mtext('pgplot.contour test', 't')
-- draw map
pgplot.beginbuffer()
for i = 1, 20 do
	local alev = fmin + i * (fmax - fmin) / 20
	local lw, ci, ls
	if math.mod(i, 5) == 0 then lw = 3 else lw = 1 end
	if i < 10 then
		ci = 2
		ls = 2
	else
		ci = 4
		ls = 1
	end
	pgplot.setcolorindex(ci)
	pgplot.setlinestyle(ls)
	pgplot.setlinewidth(lw)
	pgplot.cont(f, alev, false)
end
-- reset
pgplot.setcolorindex()
pgplot.setlinestyle()
pgplot.setlinewidth()
pgplot.endbuffer()

-- demo 3
local n1 = {3, 4, 5, 5, 6, 8}
local n2 = {1, 1, 1, 2, 1, 3}
local n = table.getn(n1)
local label = {
	'fill style 1 (solid)',
	'fill style 2 (outline)',
	'fill style 3 (hatched)',
	'fill style 4 (cross-hatched)'
}
-- start viewport and window
pgplot.beginbuffer()
pgplot.save()
pgplot.newpage()
pgplot.setviewport(0.0, 1.0, 0.0, 1.0)
pgplot.setwindowvp(0.0, 10.0, 0.0, 10.0)
-- labels
pgplot.setcolorindex(1)
pgplot.mtext('routines polygon, circle, rectangle with fill', 't',
		-2.0, 0.5, 0.5)
-- draw
for k = 1, 4 do
	pgplot.setcolorindex(1);
	local y0 = 10.0 - 2.0 * k
	pgplot.text(label[k], 0.2, y0 + 0.6)
	pgplot.setfillstyle(k)
	for i = 1, n do
		local x = {}
		local y = {}
		pgplot.setcolorindex(i)
		for j = 1, n1[i] do
			x[j] =  i + 0.5 * math.cos(n2[i] * 2 * math.pi * (j-1) / n1[i])
			y[j] = y0 + 0.5 * math.sin(n2[i] * 2 * math.pi * (j-1) / n1[i])
		end
		pgplot.polygon(x, y)
	end
	pgplot.setcolorindex(7)
	pgplot.sethatchingstyle(0.0, 1.0, 0.0)
	pgplot.circle(7.0, y0, 0.5)
	pgplot.setcolorindex(8)
	pgplot.sethatchingstyle(-45.0, 1.0, 0.0)
	pgplot.rectangle(7.8, 9.5, y0 - 0.5, y0 + 0.5)
end
pgplot.unsave()
pgplot.endbuffer()

-- finalize
pgplot.finish()

