/* {=================================================================
 *
 * Float buffer routines
 * See Copyright Notice in luapgplot.h
 * $Id: $
 *
 * ==================================================================} */

#include "fbuffer.h"

/* alloc buffers */
static fbuffer *fbuffer_new (lua_State *L, size_t size) {
  fbuffer *fb = lua_newuserdata(L, sizeof(fbuffer) + size * sizeof(float));
  fb->data = (float *) ((fbuffer *) fb + 1);
  fb->size = size;
  fb->status = BUF_FREE;
  return fb;
}

/* get a buffer from buffer bag at pos s.t. buffer->size >= size */
fbuffer *getfbuffer (lua_State *L, int pos, size_t size) {
  fbuffer *fb = NULL;
  fbuffer *curr_fb;
  int found = 0; /* flag */
  int i, n = (int) lua_objlen(L, pos);
  /* search best fb: either max size or the first b s.t. b->size >= size */
  for (i = 0; i < n && !found; i++) {
    lua_rawgeti(L, pos, i + 1);
    curr_fb = (fbuffer *) lua_touserdata(L, -1);
    if (curr_fb->status == BUF_FREE) {
      if (curr_fb->size >= size) { /* found */
        fb = curr_fb;
        found = 1;
      }
      else if (!fb || curr_fb->size>fb->size) fb = curr_fb;
    }
    lua_pop(L, 1);
  }
  n = (fb) ? fb->pos : n + 1; /* curr position on new last */
  if (!fb || !found) {
    fb = fbuffer_new(L, size);
    fb->pos = n;
    lua_rawseti(L, pos, fb->pos);
  }
  fb->status = BUF_BUSY;
  return fb;
}

