/* {=================================================================
 *
 * luapgplot.h
 * Lua interface to PGPLOT
 * Luis Carvalho (carvalho @ dam.brown.edu)
 * See Copyright Notice at the bottom of this file
 * $Id: $
 *
 * ==================================================================} */

#ifndef luapgplot_h
#define luapgplot_h

#include <lua.h>
#include "fbuffer.h"

#define LUAPGPLOT_VERSION "LuaPGPLOT 0.1"
#define LUAPGPLOT_COPYRIGHT "Copyright (C) 2006 Luis Carvalho"
#define LUAPGPLOT_AUTHORS "Luis Carvalho"
#define LUAPGPLOT_LIBNAME "pgplot"

#define FBUF_INDEX LUA_ENVIRONINDEX
#define STD_SYMBOL (4) /* circle */
#define STD_NSAMPLES (100)
#define MAX_NSAMPLES (1000)
#define MAX_TYPE_SIZE (8)
#define MAX_DESCR_SIZE (64)

/* Prototypes */
void pgarro_ (float *x1, float *y1, float *x2, float *y2);
void pgask_ (int *flag);
void pgbbuf_ (void);
int pgbeg_ (int *unit, const char *file, int *nxsub, int *nysub, int size);
void pgbin_ (int *nbin, float *x, float *data, int *center);
void pgbox_ (const char *xopt, float *xtick, int *nxsub,
		const char *yopt, float *ytick, int *nysub, int xsize, int ysize);
void pgcirc_ (float *xcent, float *ycent, float *radius);
void pgclos_ (void);
void pgconl_ (float *a, int *idim, int *jdim, int *i1, int *i2,
		int *j1, int *j2, float *c, float *tr, const char *label, int *intval,
		int *minint, int lsize);
void pgcont_ (float *a, int *idim, int *jdim, int *i1, int *i2,
		int *j1, int *j2, float *c, int *nc, float *tr);
void pgctab_ (float *l, float *r, float *g, float *b, int *nc, float *contra,
		float *bright);
void pgdraw_ (float *x, float *y);
void pgebuf_ (void);
void pgend_ (void);
void pgenv_ (float *xmin, float *xmax, float *ymin, float *ymax,
		int *just, int *axis);
void pgeras_ (void);
void pggray_ (float *a, int *idim, int *jdim, int *i1, int *i2,
		int *j1, int *j2, float *fg, float *bg, float *tr);
void pghist_ (int *n, float *data, float *datmin, float *datmax, int *nbin,
		int *pgflag);
void pgiden_ (void);
void pginit_ (void);
void pgimag_ (float *a, int *idim, int *jdim, int *i1, int *i2,
		int *j1, int *j2, float *a1, float *a2, float *tr);
void pglab_ (const char *xlbl, const char *ylbl, const char *toplbl,
		int xsize, int ysize, int topsize);
void pgldev_ (void);
void pglen_ (int *units, const char *string, float *xl, float *yl, int size);
void pgline_ (int *n, float *xpts, float *ypts);
void pgmove_ (float *x, float *y);
void pgmtxt_ (const char *side, float *disp, float *coord, float *fjust,
		const char *text, int ssize, int tsize);
int pgopen_ (const char *device, int dsize);
void pgpage_ (void);
void pgpanl_ (int *ix, int *iy);
void pgpap_ (float *width, float *aspect);
void pgpoly_ (int *n, float *xpts, float *ypts);
void pgpt_ (int *n, float *xpts, float *ypts, int *symbol);
void pgptxt_ (float *x, float *y, float *angle, float *fjust,
		const char *text, int tsize);
void pgqah_ (int *fs, float *angle, float *barb);
void pgqcf_ (int *font);
void pgqch_ (float *size);
void pgqci_ (int *ci);
void pgqcir_ (int *icilo, int *icihi);
void pgqclp_ (int *state);
void pgqcol_ (int *ci1, int *ci2);
void pgqcr_ (int *ci, float *cr, float *cg, float *cb);
void pgqdt_ (int *n, char *type, int *tlen, char *descr,
		int *dlen, int *inter, int tl, int dl);
void pgqfs_ (int *fs);
void pgqhs_ (float *angle, float *sepn, float *phase);
void pgqid_ (int *id);
void pgqinf_ (const char *item, char *value, int *length, int il);
void pgqitf_ (int *itf);
void pgqls_ (int *ls);
void pgqlw_ (int *lw);
void pgqndt_ (int *n);
void pgqpos_ (float *x, float *y);
void pgqtbg_ (int *tbci);
void pgqvp_ (int *units, float *x1, float *x2, float *y1, float *y2);
void pgqvsz_ (int *units, float *x1, float *x2, float *y1, float *y2);
void pgqwin_ (float *x1, float *x2, float *y1, float *y2);
void pgrect_ (float *x1, float *x2, float *y1, float *y2);
void pgrnge_ (float *x1, float *x2, float *xlo, float *xhi);
void pgsah_ (int *fs, float *angle, float *barb);
void pgsave_ (void);
void pgunsa_ (void);
void pgscf_ (int *font);
void pgsch_ (float *size);
void pgsci_ (int *ci);
void pgscir_ (int *icilo, int *icihi);
void pgsclp_ (int *state);
void pgscr_ (int *ci, float *cr, float *cg, float *cb);
void pgscrl_ (float *dx, float *dy);
void pgscrn_ (int *ci, const char *name, int *ier, int nsize);
void pgsfs_ (int *fs);
void pgshls_ (int *ci, float *ch, float *cl, float *cs);
void pgshs_ (float *angle, float *sepn, float *phase);
void pgsitf_ (int *itf);
void pgslct_ (int *id);
void pgsls_ (int *ls);
void pgslw_ (int *lw);
void pgstbg_ (int *tbci);
void pgsubp_ (int *nxsub, int *nysub);
void pgsvp_ (float *xleft, float *xright, float *ybot, float *ytop);
void pgswin_ (float *x1, float *x2, float *y1, float *y2);
void pgtbox_ (const char *xopt, float *xtick, int *nxsub,
		const char *yopt, float *ytick, int *nysub, int xsize, int ysize);
void pgtext_ (float *x, float *y, const char *text, int tsize);
void pgupdt_ (void);
void pgvect_ (float *a, float *b, int *idim, int *jdim, int *i1, int *i2,
		int *j1, int *j2, float *c, int *nc, float *tr, float *blank);
void pgvsiz_ (float *xleft, float *xright, float *ybot, float *ytop);
void pgvstd_ (void);
void pgwnad_ (float *x1, float *x2, float *y1, float *y2);

/* interface */
extern int luaopen_luapgplot (lua_State *L);


/* {=================================================================
*
* Copyright (c) 2006 Luis Carvalho
*
* Permission is hereby granted, free of charge, to any person
* obtaining a copy of this software and associated documentation files
* (the "Software"), to deal in the Software without restriction,
* including without limitation the rights to use, copy, modify,
* merge, publish, distribute, sublicense, and/or sell copies of the
* Software, and to permit persons to whom the Software is furnished
* to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be
* included in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
* BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
* ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
* CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*
* ==================================================================} */

#endif
